{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm \N{U+0e19}.",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM G y",
    GyMMMEEEEd => "EEEE\N{U+0e17}\N{U+0e35}\N{U+0e48} d MMM G y",
    GyMMMEd => "E d MMM G y",
    GyMMMd => "d MMM G y",
    GyMd => "d/M/GGGGG y",
    H => "HH",
    Hm => "HH:mm \N{U+0e19}.",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEEEEd => "EEEE\N{U+0e17}\N{U+0e35}\N{U+0e48} d MMM",
    MMMEd => "E d MMM",
    MMMMEEEEd => "EEEE\N{U+0e17}\N{U+0e35}\N{U+0e48} d MMMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "\N{U+0e2a}\N{U+0e31}\N{U+0e1b}\N{U+0e14}\N{U+0e32}\N{U+0e2b}\N{U+0e4c}\N{U+0e17}\N{U+0e35}\N{U+0e48} W \N{U+0e02}\N{U+0e2d}\N{U+0e07}\N{U+0e40}\N{U+0e14}\N{U+0e37}\N{U+0e2d}\N{U+0e19}MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm \N{U+0e19}. a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEEEEd => "EEEE\N{U+0e17}\N{U+0e35}\N{U+0e48} d MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMMEEEEd => "EEEE\N{U+0e17}\N{U+0e35}\N{U+0e48} d MMMM y",
    yMMMMEd => "E d MMMM y",
    yMMMMd => "d MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ G y",
    "yw-count-other" => "\N{U+0e2a}\N{U+0e31}\N{U+0e1b}\N{U+0e14}\N{U+0e32}\N{U+0e2b}\N{U+0e4c}\N{U+0e17}\N{U+0e35}\N{U+0e48} w \N{U+0e02}\N{U+0e2d}\N{U+0e07}\N{U+0e1b}\N{U+0e35} Y",
  },
  code => "th-TH",
  date_format_full => "EEEE\N{U+0e17}\N{U+0e35}\N{U+0e48} d MMMM G y",
  date_format_long => "d MMMM G y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0e08}.",
    "\N{U+0e2d}.",
    "\N{U+0e1e}.",
    "\N{U+0e1e}\N{U+0e24}.",
    "\N{U+0e28}.",
    "\N{U+0e2a}.",
    "\N{U+0e2d}\N{U+0e32}.",
  ],
  day_format_narrow => [
    "\N{U+0e08}",
    "\N{U+0e2d}",
    "\N{U+0e1e}",
    "\N{U+0e1e}\N{U+0e24}",
    "\N{U+0e28}",
    "\N{U+0e2a}",
    "\N{U+0e2d}\N{U+0e32}",
  ],
  day_format_wide => [
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e08}\N{U+0e31}\N{U+0e19}\N{U+0e17}\N{U+0e23}\N{U+0e4c}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e2d}\N{U+0e31}\N{U+0e07}\N{U+0e04}\N{U+0e32}\N{U+0e23}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e1e}\N{U+0e38}\N{U+0e18}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e1e}\N{U+0e24}\N{U+0e2b}\N{U+0e31}\N{U+0e2a}\N{U+0e1a}\N{U+0e14}\N{U+0e35}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e28}\N{U+0e38}\N{U+0e01}\N{U+0e23}\N{U+0e4c}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e40}\N{U+0e2a}\N{U+0e32}\N{U+0e23}\N{U+0e4c}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e2d}\N{U+0e32}\N{U+0e17}\N{U+0e34}\N{U+0e15}\N{U+0e22}\N{U+0e4c}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0e08}.",
    "\N{U+0e2d}.",
    "\N{U+0e1e}.",
    "\N{U+0e1e}\N{U+0e24}.",
    "\N{U+0e28}.",
    "\N{U+0e2a}.",
    "\N{U+0e2d}\N{U+0e32}.",
  ],
  day_stand_alone_narrow => [
    "\N{U+0e08}",
    "\N{U+0e2d}",
    "\N{U+0e1e}",
    "\N{U+0e1e}\N{U+0e24}",
    "\N{U+0e28}",
    "\N{U+0e2a}",
    "\N{U+0e2d}\N{U+0e32}",
  ],
  day_stand_alone_wide => [
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e08}\N{U+0e31}\N{U+0e19}\N{U+0e17}\N{U+0e23}\N{U+0e4c}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e2d}\N{U+0e31}\N{U+0e07}\N{U+0e04}\N{U+0e32}\N{U+0e23}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e1e}\N{U+0e38}\N{U+0e18}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e1e}\N{U+0e24}\N{U+0e2b}\N{U+0e31}\N{U+0e2a}\N{U+0e1a}\N{U+0e14}\N{U+0e35}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e28}\N{U+0e38}\N{U+0e01}\N{U+0e23}\N{U+0e4c}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e40}\N{U+0e2a}\N{U+0e32}\N{U+0e23}\N{U+0e4c}",
    "\N{U+0e27}\N{U+0e31}\N{U+0e19}\N{U+0e2d}\N{U+0e32}\N{U+0e17}\N{U+0e34}\N{U+0e15}\N{U+0e22}\N{U+0e4c}",
  ],
  era_abbreviated => [
    "\N{U+0e01}\N{U+0e48}\N{U+0e2d}\N{U+0e19} \N{U+0e04}.\N{U+0e28}.",
    "\N{U+0e04}.\N{U+0e28}.",
  ],
  era_narrow => [
    "\N{U+0e01}\N{U+0e48}\N{U+0e2d}\N{U+0e19} \N{U+0e04}.\N{U+0e28}.",
    "\N{U+0e04}.\N{U+0e28}.",
  ],
  era_wide => [
    "\N{U+0e1b}\N{U+0e35}\N{U+0e01}\N{U+0e48}\N{U+0e2d}\N{U+0e19}\N{U+0e04}\N{U+0e23}\N{U+0e34}\N{U+0e2a}\N{U+0e15}\N{U+0e01}\N{U+0e32}\N{U+0e25}",
    "\N{U+0e04}\N{U+0e23}\N{U+0e34}\N{U+0e2a}\N{U+0e15}\N{U+0e4c}\N{U+0e28}\N{U+0e31}\N{U+0e01}\N{U+0e23}\N{U+0e32}\N{U+0e0a}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %e %b %Ey %H:%M:%S %Z",
  glibc_date_format => "%d/%m/%Ey",
  glibc_datetime_format => "%a %e %b %Ey, %H:%M:%S",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Thai",
  month_format_abbreviated => [
    "\N{U+0e21}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e1e}.",
    "\N{U+0e21}\N{U+0e35}.\N{U+0e04}.",
    "\N{U+0e40}\N{U+0e21}.\N{U+0e22}.",
    "\N{U+0e1e}.\N{U+0e04}.",
    "\N{U+0e21}\N{U+0e34}.\N{U+0e22}.",
    "\N{U+0e01}.\N{U+0e04}.",
    "\N{U+0e2a}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e22}.",
    "\N{U+0e15}.\N{U+0e04}.",
    "\N{U+0e1e}.\N{U+0e22}.",
    "\N{U+0e18}.\N{U+0e04}.",
  ],
  month_format_narrow => [
    "\N{U+0e21}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e1e}.",
    "\N{U+0e21}\N{U+0e35}.\N{U+0e04}.",
    "\N{U+0e40}\N{U+0e21}.\N{U+0e22}.",
    "\N{U+0e1e}.\N{U+0e04}.",
    "\N{U+0e21}\N{U+0e34}.\N{U+0e22}.",
    "\N{U+0e01}.\N{U+0e04}.",
    "\N{U+0e2a}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e22}.",
    "\N{U+0e15}.\N{U+0e04}.",
    "\N{U+0e1e}.\N{U+0e22}.",
    "\N{U+0e18}.\N{U+0e04}.",
  ],
  month_format_wide => [
    "\N{U+0e21}\N{U+0e01}\N{U+0e23}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e01}\N{U+0e38}\N{U+0e21}\N{U+0e20}\N{U+0e32}\N{U+0e1e}\N{U+0e31}\N{U+0e19}\N{U+0e18}\N{U+0e4c}",
    "\N{U+0e21}\N{U+0e35}\N{U+0e19}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e40}\N{U+0e21}\N{U+0e29}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e1e}\N{U+0e24}\N{U+0e29}\N{U+0e20}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e21}\N{U+0e34}\N{U+0e16}\N{U+0e38}\N{U+0e19}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e01}\N{U+0e23}\N{U+0e01}\N{U+0e0e}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e2a}\N{U+0e34}\N{U+0e07}\N{U+0e2b}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e01}\N{U+0e31}\N{U+0e19}\N{U+0e22}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e15}\N{U+0e38}\N{U+0e25}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e1e}\N{U+0e24}\N{U+0e28}\N{U+0e08}\N{U+0e34}\N{U+0e01}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e18}\N{U+0e31}\N{U+0e19}\N{U+0e27}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0e21}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e1e}.",
    "\N{U+0e21}\N{U+0e35}.\N{U+0e04}.",
    "\N{U+0e40}\N{U+0e21}.\N{U+0e22}.",
    "\N{U+0e1e}.\N{U+0e04}.",
    "\N{U+0e21}\N{U+0e34}.\N{U+0e22}.",
    "\N{U+0e01}.\N{U+0e04}.",
    "\N{U+0e2a}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e22}.",
    "\N{U+0e15}.\N{U+0e04}.",
    "\N{U+0e1e}.\N{U+0e22}.",
    "\N{U+0e18}.\N{U+0e04}.",
  ],
  month_stand_alone_narrow => [
    "\N{U+0e21}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e1e}.",
    "\N{U+0e21}\N{U+0e35}.\N{U+0e04}.",
    "\N{U+0e40}\N{U+0e21}.\N{U+0e22}.",
    "\N{U+0e1e}.\N{U+0e04}.",
    "\N{U+0e21}\N{U+0e34}.\N{U+0e22}.",
    "\N{U+0e01}.\N{U+0e04}.",
    "\N{U+0e2a}.\N{U+0e04}.",
    "\N{U+0e01}.\N{U+0e22}.",
    "\N{U+0e15}.\N{U+0e04}.",
    "\N{U+0e1e}.\N{U+0e22}.",
    "\N{U+0e18}.\N{U+0e04}.",
  ],
  month_stand_alone_wide => [
    "\N{U+0e21}\N{U+0e01}\N{U+0e23}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e01}\N{U+0e38}\N{U+0e21}\N{U+0e20}\N{U+0e32}\N{U+0e1e}\N{U+0e31}\N{U+0e19}\N{U+0e18}\N{U+0e4c}",
    "\N{U+0e21}\N{U+0e35}\N{U+0e19}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e40}\N{U+0e21}\N{U+0e29}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e1e}\N{U+0e24}\N{U+0e29}\N{U+0e20}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e21}\N{U+0e34}\N{U+0e16}\N{U+0e38}\N{U+0e19}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e01}\N{U+0e23}\N{U+0e01}\N{U+0e0e}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e2a}\N{U+0e34}\N{U+0e07}\N{U+0e2b}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e01}\N{U+0e31}\N{U+0e19}\N{U+0e22}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e15}\N{U+0e38}\N{U+0e25}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
    "\N{U+0e1e}\N{U+0e24}\N{U+0e28}\N{U+0e08}\N{U+0e34}\N{U+0e01}\N{U+0e32}\N{U+0e22}\N{U+0e19}",
    "\N{U+0e18}\N{U+0e31}\N{U+0e19}\N{U+0e27}\N{U+0e32}\N{U+0e04}\N{U+0e21}",
  ],
  name => "Thai Thailand",
  native_language => "\N{U+0e44}\N{U+0e17}\N{U+0e22}",
  native_name => "\N{U+0e44}\N{U+0e17}\N{U+0e22} \N{U+0e44}\N{U+0e17}\N{U+0e22}",
  native_script => undef,
  native_territory => "\N{U+0e44}\N{U+0e17}\N{U+0e22}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 1",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 2",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 3",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 1",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 2",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 3",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 1",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 2",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 3",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 1",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 2",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 3",
    "\N{U+0e44}\N{U+0e15}\N{U+0e23}\N{U+0e21}\N{U+0e32}\N{U+0e2a} 4",
  ],
  script => undef,
  territory => "Thailand",
  time_format_full => "H \N{U+0e19}\N{U+0e32}\N{U+0e2c}\N{U+0e34}\N{U+0e01}\N{U+0e32} mm \N{U+0e19}\N{U+0e32}\N{U+0e17}\N{U+0e35} ss \N{U+0e27}\N{U+0e34}\N{U+0e19}\N{U+0e32}\N{U+0e17}\N{U+0e35} zzzz",
  time_format_long => "H \N{U+0e19}\N{U+0e32}\N{U+0e2c}\N{U+0e34}\N{U+0e01}\N{U+0e32} mm \N{U+0e19}\N{U+0e32}\N{U+0e17}\N{U+0e35} ss \N{U+0e27}\N{U+0e34}\N{U+0e19}\N{U+0e32}\N{U+0e17}\N{U+0e35} z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
